SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
    var _timeout = 0;
    var _mass_action_selector;
    
    function ____ ( fct ) {
        _timeout += fct;
    }
    
    self.do = function () {
        switch ( __shinken_test_type ) {
            case "00046":
                //FILTER LIST
                _timeout = 500;
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test_auto(', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test)auto(', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '""', 0, 1 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '((test_auto)|(test_auto)&test_auto)|test_auto', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '(()', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '() )(', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '()', 0, 1 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'auto|()', 0, 1 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '"test_"auto""', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test_"auto"', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '"test!_auto"<', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!"test!_auto"', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '=!"test!_auto"', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '(1)(2)', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '(1)&(2)', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '(1)|(2)', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '>dd<', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '""|test_auto', 0, 1 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '&test_auto', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test<auto', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test*auto', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '&&', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '^auto|="test"', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '"avec espaces" | ^test', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!=""', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!>"test_auto"', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '&"', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test_auto"', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!!', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!fdsfsd!', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!>fdsfsd!', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '!(>fdsfsd)&!s', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '(||)', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '(||)test', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '=test*', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '=test<', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '=test>', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '=test!', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '=!', 1, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test_auto*"test_auto"', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'test_auto*"("', 0, 0 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', '>test_auto*(test_auto)', 0, 0 ) );
                break;
            case "00082":
                //LIST HOST WORKING AREA

                switch ( __phase ) {
                    case 1:
                        if ( MANAGER.__instance_element_distributor.current_user.uuid !== '35000000000000000000000000000000' ) {
                            SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                        }
                        break;
                    case 2:
                        //STRUCTURE ET SELECTOR
                        _mass_action_selector = document.getElementById( "id-shinken-select-mass-action" );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'isAdmin', 'True', 'data body is-admin' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'stateWorkFlow', 'save-in-working-area', 'data body save working area' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( "saving-log" ), "block de log" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-action-panel" ), "Block de titre" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-list-panel" ), "Block de list" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, _mass_action_selector.querySelector( '.shinken-option-separator' ), "shinken-option-separator" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.doesntExist( _timeout, document.getElementById( 'id-shinken-actions-staging' ), "#id-shinken-actions-staging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "id-shinken-mass-action-row" ), "block de mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "btn-action-launch" ), "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector, "selecteur mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, _mass_action_selector.querySelector( '.shinken-list-select' ), "options mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isText( _timeout, _mass_action_selector.querySelector( ".shinken-select-selector" ), "", "text du selecteur de mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector.querySelector( '.shinken-list-select' ), "options mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-working-area' ), "option mass action specifique working area" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ), "option mass action specifique stagging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ).querySelector( '.shinken-optgroup-title' ), "#id-shinken-actions-host-staging .shinken-optgroup-title" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-4' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-5' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.DISABLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", true, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        __do_next = false;
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.SUBMIT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", true, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", true, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        __do_next = false;
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-7' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 8:
                        _mass_action_selector = document.getElementById( "id-shinken-select-mass-action" );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ).querySelector( '.shinken-optgroup-title' ), "#id-shinken-actions-host-staging .shinken-optgroup-title" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector.querySelector( '.shinken-list-select' ), "options mass action 2" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-working-area' ), "option mass action specifique working area" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ), "option mass action specifique stagging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.doesntExist( _timeout, document.getElementById( 'shinken-tab-staging-for-element-without-staging' ), "option mass action specifique stagging (element without staging)" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 9:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.APPLY ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        __do_next = false;
                        break;
                    case 10:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.ENABLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        __do_next = false;
                        break;
                }
                break;
            case "00083":
                //LIST HOST STAGGING
                switch ( __phase ) {
                    case 1:
                        //STRUCTURE ET SELECTOR
                        _mass_action_selector = document.getElementById( "id-shinken-select-mass-action" );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'isAdmin', 'True', 'data body is-admin' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'stateWorkFlow', 'save-direct-in-staging', 'data body save working area' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( "saving-log" ), "block de log" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-action-panel" ), "Block de titre" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-list-panel" ), "Block de list" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, _mass_action_selector.querySelector( '.shinken-option-separator' ), "shinken-option-separator" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ).querySelector( '.shinken-optgroup-title' ), "#id-shinken-actions-host-staging .shinken-optgroup-title" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, document.querySelector( ".shinken-row-workflow-title" ), 'height', 0, "block du workflow" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isText( _timeout, _mass_action_selector.querySelector( ".shinken-select-selector" ), "", "text du selecteur de mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector.querySelector( '.shinken-list-select' ), "options mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-working-area' ), "option mass action specifique working area" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ), "option mass action specifique stagging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ).querySelector( '.shinken-optgroup-title' ), "#id-shinken-actions-host-staging .shinken-optgroup-title" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'shinken-tab-staging' ), "option mass action specifique stagging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'shinken-tab-staging-for-element-without-staging' ), "option mass action specifique stagging (element without staging)" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00083-3' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00083-6' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.REJECT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", true, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", true, "bouton exécuter comment" ) );
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.APPLY ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", true, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        __do_next = false;
                        break;
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00083-8' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                        break;
                    case 9:
                        break;
                    case 10:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                        break;
                }
                break;
            case "00084":
                //LIST ALL ELEMENTS
                switch ( __phase ) {
                    case 1:
                        //STRUCTURE ET SELECTOR
                        _mass_action_selector = document.getElementById( "id-shinken-select-mass-action" );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'isAdmin', 'True', 'data body is-admin' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'stateWorkFlow', 'save-direct-in-staging', 'data body save working area' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( "saving-log" ), "block de log" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-action-panel" ), "Block de titre" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-list-panel" ), "Block de list" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, _mass_action_selector.querySelector( '.shinken-option-separator' ), "shinken-option-separator" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ).querySelector( '.shinken-optgroup-title' ), "#id-shinken-actions-host-staging .shinken-optgroup-title" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, document.querySelector( ".shinken-row-workflow-title" ), 'height', 0, "block du workflow" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isText( _timeout, _mass_action_selector.querySelector( ".shinken-select-selector" ), "", "text du selecteur de mass action" ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector.querySelector( '.shinken-list-select' ), "options mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-working-area' ), "option mass action specifique working area" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ), "option mass action specifique stagging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ).querySelector( '.shinken-optgroup-title' ), "#id-shinken-actions-host-staging .shinken-optgroup-title" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-staging' ), 'id-shinken-actions-staging' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-staging' ).querySelector( '.shinken-optgroup-title' ), "#actions-staging .shinken-optgroup-title" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector.querySelector( '.shinken-option-separator' ), "shinken-option-separator" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'shinken-tab-staging' ), "option mass action specifique stagging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'shinken-tab-staging-for-element-without-staging' ), "option mass action specifique stagging (element without staging)" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 20 ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 20 ) );
                        break;
                }
                break;
            case "00085":
                //LIST HOST TPL
                switch ( __phase ) {
                    case 1:
                        //STRUCTURE ET SELECTOR
                        _mass_action_selector = document.getElementById( "id-shinken-select-mass-action" );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'isAdmin', 'True', 'data body is-admin' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'stateWorkFlow', 'save-direct-in-staging', 'data body save working area' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( "saving-log" ), "block de log" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-action-panel" ), "Block de titre" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".elements-list-panel" ), "Block de list" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, _mass_action_selector.querySelector( '.shinken-option-separator' ), "shinken-option-separator" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( "shinken-row-workflow-title" ), "block du workflow" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isText( _timeout, _mass_action_selector.querySelector( ".shinken-select-selector" ), "", "text du selecteur de mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector.querySelector( '.shinken-list-select' ), "options mass action" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'id-shinken-actions-host-working-area' ), "option mass action specifique working area" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ), "option mass action specifique stagging" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( 'id-shinken-actions-staging' ), 'id-shinken-actions-staging' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, _mass_action_selector.querySelector( '.shinken-option-separator' ), "shinken-option-separator" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 9 ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 9 ) );
                        break;
                }
                break;
            case "00086":
                //LIST FILTER
                __do_next = false;
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.ACTION.clickOnInput( _timeout, 'sources' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.ACTION.moveAutoCursorDown( _timeout, 'sources' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '()', 0, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name', false ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '()' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 11, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.validation_value( _timeout, 'display_name', 0, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '(&&)', 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name', true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_TOOLTIP.TEST.containsText( _timeout, _( "validator.filter.call_to_list_avoid" ) ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PHASE.ACTION.refreshPage( _timeout, 'display_name', true ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '()' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 11, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '1  test', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '1  test' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 2, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '1*list', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '1*list' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 4, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>8&case4', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>8&case4' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 1, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>8&case4|3', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>8&case4|3' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 2, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>8&case4|3|new', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>8&case4|3|new' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 3, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '="3  test filter list working area"', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 9:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '="3  test filter list working area"' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 1, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '!="3  test filter list working area"', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 10:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '!="3  test filter list working area"' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 10, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '!(>1)&!4', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 11:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '!(>1)&!4' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 6, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>test', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 12:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>test' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 0, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>1', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 13:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>1' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 3, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>1 ', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 14:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>1 ' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 3, 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>"1 "', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 15:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>"1 "' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 1, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '>"1" | >"2"', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    case 16:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_FILTER.TEST.hasValue( _timeout, 'display_name', '>"1" | >"2"' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.elementsNumber( _timeout, 4, 1, 0 ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'display_name', '"va"lid<"', 1, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'display_name' ) );
                        break;
                    default:
                        __do_next = true;
                        break;
                }
                break;
            case "00166":
                switch ( __phase ) {
                    case 5:
                        __do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.SUBMIT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        break;
                    case 6:
                        __do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.APPLY ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        break;
                    case 7:
                        break;
                }
                break;
            case "00177":
                //CLONE MULTIPLE
                //SEF-9157
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.filterValidation( _timeout, 'host_name', 'copie', 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.simulatePressEnterToValid( _timeout, 'host_name' ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, "ALL" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectAndClickOnExecuteMassActionIfPossible( _timeout, ACTIONS.DELETE ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                        break;
                    case 4:
                    case 5:
                    case 6:
                        __do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.CLONE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        break;
                    case 7:
                        break;
                    default:
                        break;
                }
                break;
            
            case "00184":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_admin_si", "test_auto_admin_si" ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.do_mass_action_without_UI( _timeout, [403], SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.CONST.MASS_CHANGE_ACTION_IMPORT, "1" ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.do_mass_action_without_UI( _timeout, [403], SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.CONST.MASS_CHANGE_ACTION_DIFFERENCE, "1" ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
                        break;
                }
                break;
            case "00211":
                switch ( __phase ) {
                    //MAKE 16 clone
                    case 1:
                    case 2:
                    case 3:
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.CLONE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                        __do_next = false;
                    case 5:
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                        __do_next = false;
                        break;
                }
                break;
            case "00216":
                switch ( __phase ) {
                    case 1:
                        __do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.columnNumber( _timeout,16 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnConfigurationButton( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.addExtraColumn( _timeout, PROPERTY.CONST.NAME.HOSTGROUPS ) );
                        break;
                    case 2:
                        __do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.columnNumber( _timeout,17 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnConfigurationButton( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.addExtraColumn( _timeout, PROPERTY.CONST.NAME.NOTE_URL ) );
                        break;
                    case 3:
                        __do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.columnNumber( _timeout,18 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnConfigurationButton( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.addExtraColumn( _timeout, PROPERTY.CONST.NAME.NOTE_URL ) );
                        break;
                    case 4:
                        __do_next = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.columnNumber( _timeout,17 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnConfigurationButton( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.addExtraColumn( _timeout, PROPERTY.CONST.NAME.HOSTGROUPS ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.columnNumber( _timeout,16 ) );
                        break;
                }
                break;
            default:
                ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_PRODUCTION_RUN.do( _timeout ) );
        }
        return _timeout;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_LIST_RUN || {} );
